#!/bin/bash -e

[ ! -f ca.key ] \
&& openssl genrsa \
-des3 \
-out ca.key \
-passout pass:changeit \
4096 \
&& rm -f ca.crt \
&& echo "ca.key generated"

[ ! -f ca.crt ] \
&& openssl req -x509 \
-new \
-key ca.key \
-passin pass:changeit \
-days 1024 \
-sha256 \
-subj "/C=US/O=Confluent/CN=Test CA" \
-out ca.crt \
&& echo "ca.crt generated"

[ ! -f test.key ] \
&& openssl genrsa \
-des3 \
-out test.key \
-passout pass:changeit \
2048 \
&& rm -f test.csr \
&& echo "test.key generated"

[ ! -f test.csr ] \
&& openssl req \
-new \
-key test.key \
-passin pass:changeit \
-sha256 \
-subj "/C=US/O=Confluent/CN=Test" \
-out test.csr \
&& rm -f test.crt \
&& echo "test.csr generated"

[ ! -f test.crt ] \
&& openssl x509 \
-req \
-CA ca.crt \
-CAkey ca.key \
-CAcreateserial \
-in test.csr \
-out test.crt \
-days 3650 \
-sha256  \
-passin pass:changeit \
-extfile <(printf "basicConstraints=CA:FALSE\nkeyUsage=digitalSignature,keyEncipherment\nextendedKeyUsage=clientAuth") \
&& rm -f test.p12 \
&& echo "test.crt generated"

[ ! -f test.p12 ] \
&& openssl pkcs12 \
-export \
-chain \
-CAfile ca.crt \
-name test \
-in test.crt \
-inkey test.key \
-passin pass:changeit \
-passout pass:changeit \
-out test.p12 \
&& echo "test.p12 generated"

exit 0
